@@ -1,21 +1,8 @@
-/***************************************************************************
- *   Copyright (C) 2011 by Vishesh Yadav <vishesh3y@gmail.com>             *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA            *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2011 Vishesh Yadav <vishesh3y@gmail.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "pushdialog.h"
 #include "hgconfig.h"
@@ -95,7 +82,7 @@ void HgPushDialog::slotOutSelChanged()
         return;
     }
 
-    QString changeset = m_outChangesList->item(m_outChangesList->currentRow(), 0)->text().split(' ', QString::SkipEmptyParts).takeLast();
+    QString changeset = m_outChangesList->item(m_outChangesList->currentRow(), 0)->text().split(' ', Qt::SkipEmptyParts).takeLast();
 
     QStringList args; 
     args << QLatin1String("-r");
@@ -122,7 +109,7 @@ void HgPushDialog::getHgChangesArguments(QStringList &args)
 
 void HgPushDialog::parseUpdateChanges(const QString &input)
 {
-    QStringList list = input.split("  ", QString::SkipEmptyParts);
+    QStringList list = input.split("  ", Qt::SkipEmptyParts);
     QTableWidgetItem *changeset = new QTableWidgetItem;
     QTableWidgetItem *date = new QTableWidgetItem;
     QTableWidgetItem *summary = new QTableWidgetItem;
