@@ -72,9 +72,6 @@ enum columns_t {
     columnStatus
 };
 
-const QStringList tableHeader = { i18nc("@title:column", "Path"),
-                                  i18nc("@title:column", "Status") };
-
 SvnCommitDialog::SvnCommitDialog(const QHash<QString, KVersionControlPlugin::ItemVersion> *versionInfo, const QStringList& context, QWidget *parent) :
     QDialog(parent),
     m_versionInfoHash(versionInfo),
@@ -116,26 +113,26 @@ SvnCommitDialog::SvnCommitDialog(const QHash<QString, KVersionControlPlugin::Ite
      */
     m_actRevertFile = new QAction(i18nc("@item:inmenu", "Revert"), this);
     m_actRevertFile->setIcon(QIcon::fromTheme("document-revert"));
-    connect(m_actRevertFile, &QAction::triggered, [this] () {
+    connect(m_actRevertFile, &QAction::triggered, this, [this] () {
         const QString filePath = m_actRevertFile->data().value<svnCommitEntryInfo_t>().localPath;
         Q_EMIT revertFiles(QStringList() << filePath);
     } );
 
     m_actDiffFile = new QAction(i18nc("@item:inmenu", "Show changes"), this);
     m_actDiffFile->setIcon(QIcon::fromTheme("view-split-left-right"));
-    connect(m_actDiffFile, &QAction::triggered, [this] () {
+    connect(m_actDiffFile, &QAction::triggered, this, [this] () {
         const QString filePath = m_actDiffFile->data().value<svnCommitEntryInfo_t>().localPath;
         Q_EMIT diffFile(filePath);
     } );
 
     m_actAddFile = new QAction(i18nc("@item:inmenu", "Add file"), this);
     m_actAddFile->setIcon(QIcon::fromTheme("list-add"));
-    connect(m_actAddFile, &QAction::triggered, [this] () {
+    connect(m_actAddFile, &QAction::triggered, this, [this] () {
         const QString filePath = m_actAddFile->data().value<svnCommitEntryInfo_t>().localPath;
         Q_EMIT addFiles(QStringList() << filePath);
     } );
 
-    connect(buttonBox, &QDialogButtonBox::accepted, [this] () {
+    connect(buttonBox, &QDialogButtonBox::accepted, this, [this] () {
         // Form a new context list from an existing one and a possibly modified m_versionInfoHash (some
         // files from original context might no longer be in m_versionInfoHash).
         QStringList context = makeContext(m_context, m_versionInfoHash);
@@ -156,6 +153,8 @@ SvnCommitDialog::SvnCommitDialog(const QHash<QString, KVersionControlPlugin::Ite
      */
     setWindowTitle(i18nc("@title:window", "SVN Commit"));
 
+    const QStringList tableHeader = { i18nc("@title:column", "Path"),
+                                      i18nc("@title:column", "Status") };
     m_changes->setColumnCount(tableHeader.size());
     m_changes->setHorizontalHeaderLabels(tableHeader);
     m_changes->horizontalHeader()->setSectionResizeMode(QHeaderView::Stretch);
